@@ -92,6 +92,7 @@ setMethod("spTransform", signature("ST", "CRS"), spTransform.ST)
 summary.ST = function(object, ...) {
     obj = list()
     obj[["class"]] = class(object)
+    obj[["dim"]] = dim(object)
 	obj[["sp"]] = summary(object@sp)
 	obj[["time"]] = summary(object@time)
     if ("data" %in% slotNames(object))
@@ -105,9 +106,9 @@ setMethod("summary", "ST", summary.ST)
 
 print.summary.ST = function(x, ...) {
     cat(paste("Object of class ", x[["class"]], "\n", sep = ""))
-	# cat("[[Dimensions (s,t,attr): ")
-	# cat(paste(dim(x), collapse = " "))
-	# cat("]]\n")
+	cat(" with Dimensions (s, t, attr): (")
+	cat(paste(x[["dim"]], collapse = ", "))
+	cat(")\n")
 	cat("[[Spatial:]]\n")
     print(x[["sp"]])
 	cat("[[Temporal:]]\n")
